@@ -1043,8 +1043,8 @@ synthv1_voice::synthv1_voice ( synthv1_impl *pImpl ) :
 
 synthv1_impl::synthv1_impl (
 	synthv1 *pSynth, uint16_t nchannels, float srate )
-	: m_controls(pSynth), m_programs(pSynth),
-		m_midi_in(pSynth), m_bpm(180.0f), m_running(false)
+	: m_controls(pSynth), m_programs(pSynth), m_midi_in(pSynth),
+		m_bpm(180.0f), m_nvoices(0), m_running(false)
 {
 	// max env. stage length (default)
 	m_dco1.envtime0 = m_dco2.envtime0 = 0.0001f * MAX_ENV_MSECS;
