@@ -802,6 +802,11 @@ synthv1widget::synthv1widget ( QWidget *pParent )
 		SIGNAL(toggled(bool)),
 		SLOT(swapParams(bool)));
 
+	// Randomize params...
+	QObject::connect(m_ui.PanicButton,
+		SIGNAL(clicked()),
+		SLOT(panic()));
+	
 	// Direct stacked-page signal/slot
 	QObject::connect(m_ui.TabBar, SIGNAL(currentChanged(int)),
 		m_ui.StackedWidget, SLOT(setCurrentIndex(int)));
@@ -1230,6 +1235,15 @@ void synthv1widget::swapParams ( bool bOn )
 }
 
 
+// Panic: all-notes/sound-off (reset).
+void synthv1widget::panic (void)
+{
+	synthv1_ui *pSynthUi = ui_instance();
+	if (pSynthUi)
+		pSynthUi->reset();
+}
+
+
 // Reset swap params A/B group.
 void synthv1widget::resetSwapParams (void)
 {
